AeroSyncSingleAccountSuccessPayload class
Single-account success payload (default / AeroPass returning user).
- Inheritance
-
- Object
- AeroSyncSuccessPayload
- AeroSyncSingleAccountSuccessPayload
Constructors
- AeroSyncSingleAccountSuccessPayload({required String connectionId, required String clientName, required String aeroPassUserUuid})
-
const
-
AeroSyncSingleAccountSuccessPayload.fromJson(Map<
String, dynamic> json) -
factory
Properties
- aeroPassUserUuid → String
-
final
- clientName → String
-
final
- connectionId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited